#install.packages("ape")
#if (!any(rownames(installed.packages()) == "MCMCtreeR")) install.packages("MCMCtreeR")
library(MCMCtreeR, quietly = TRUE, warn.conflicts = FALSE)
library(ape)
library(dplyr)
library(tidyr)

nwk_tree<-read.tree("./MCMCTree-126-core-left-right-noOutgroups2/Euce_St-NoOutgroups.tre")
mctree<-readMCMCtree("./MCMCTree-126-core-left-right-noOutgroups2/70k/corr/combined/70k_corr_FigTree.tre")


############All_calibrations############

##creating the minimum times##

Euce.minTimes<-c("nodeOne"=0.55,"nodeSix"=0.339,"nodeSeven"=0.137)
Euce.minTimes

##creating the maximum times##
Euce.maxTimes<-c("nodeOne"=0.85,"nodeSix"=0.60,"nodeSeven"=0.33)
Euce.maxTimes

##creating the monophyletic groups###
par(mfrow=c(1,1))
plot(mctree$apePhy, cex=0.3, no.margin=TRUE)
nodelabels(cex=.5,frame="none",adj=c(1.1,-0.4))

monophyleticGroups.user <- tipDes(nwk_tree, c(151,153,284))
monophyleticGroups.user
names(monophyleticGroups.user)<-c("Root","Eucerini.Ancylaini","Anthophorula")
monophyleticGroups.user


###Skew-t####
skewT_results <-estimateSkewT(minAge = Euce.minTimes, maxAge = Euce.maxTimes, estimateShape = FALSE, shape =  c(200,50), df=2,
                              monoGroups = monophyleticGroups.user, phy = nwk_tree, plot = FALSE, estimateScale = TRUE,
                              writeMCMCtree=FALSE)

par(mfrow =c(1, 2))

for(i in 1:2)plotMCMCtree(skewT_results$parameters[i, ], 
                          method = "skewT",title =paste0("node ", i), upperTime =max(Euce.maxTimes))

###uniform root#######
uniform_results <- estimateBound(minAge = Euce.minTimes, maxAge = Euce.maxTimes,
                                 monoGroups = monophyleticGroups.user, phy = nwk_tree, plot = FALSE)
uniform_results$parameters  
###############################################################
################Plotting Priors X Posteriors###################

post_corr<-read.table("./MCMCTree-126-core-left-right-noOutgroups2/70k/corr/combined/mcmc_70k_corr.txt", header = TRUE)
post_prior_corr<-read.table("./MCMCTree-126-core-left-right-noOutgroups2/prior/corr/mcmc_20k_corr.txt", header = TRUE)

post_ind<-read.table("./MCMCTree-126-core-left-right-noOutgroups2/70k/ind/mcmc_1/2/mcmc_70k_ind.txt", header = TRUE)
post_prior_ind<-read.table("./MCMCTree-126-core-left-right-noOutgroups2/prior/ind/mcmc_20k_ind.txt", header = TRUE)

post_ind<-as_tibble(post_ind)
post_corr<-as_tibble(post_corr)
prior_ind<-as_tibble(post_prior_ind)
prior_corr<-as_tibble(post_prior_corr)

selected_rows<-c("t_n151","t_n152","t_n153","t_n154","t_n158","t_n229","t_n231","t_n232","t_n246","t_n254",
                 "t_n267","t_n268","t_n270","t_n285","t_n294")
new_row_names<-as.character(c("01","02","05*","11","14","10","04","09","13","08","03","07","13","12*","06"))

post_ind_sel<-select(post_ind, all_of(selected_rows))
post_corr_sel<-select(post_corr, all_of(selected_rows))
prior_sel<-select(prior_ind, all_of(selected_rows))

######user specified prior#############

prior_5<-plotMCMCtree(skewT_results$parameters[2, ],method = "skewT",title =paste0("node 6"), upperTime =0.92, plotMCMCtreeData = FALSE)
prior_12<-plotMCMCtree(skewT_results$parameters[3, ],method = "skewT",title =paste0("node 7"), upperTime =0.92, plotMCMCtreeData = FALSE)
prior_1<-plotMCMCtree(uniform_results$parameters[1, ],method = "bound", title = paste0("node 1"), upperTime = 0.92, plotMCMCtreeData = FALSE)


####calculating densities##########

d_n1_ind<-density(post_ind_sel$t_n151)
d_n1_p<-density(prior_sel$t_n151)
d_n2_ind<-density(post_ind_sel$t_n152)
d_n2_p_ind<-density(prior_sel$t_n152)
d_n5_ind<-density(post_ind_sel$t_n153)
d_n5_p_ind<-density(prior_sel$t_n153)
d_n11_ind<-density(post_ind_sel$t_n154)
d_n11_p_ind<-density(prior_sel$t_n154)
d_n15_ind<-density(post_ind_sel$t_n158)
d_n15_p_ind<-density(prior_sel$t_n158)
d_n10_ind<-density(post_ind_sel$t_n229)
d_n10_p_ind<-density(prior_sel$t_n229)
d_n4_ind<-density(post_ind_sel$t_n231)
d_n4_p_ind<-density(prior_sel$t_n231)
d_n9_ind<-density(post_ind_sel$t_n232)
d_n9_p_ind<-density(prior_sel$t_n232)
d_n14_ind<-density(post_ind_sel$t_n246)
d_n14_p_ind<-density(prior_sel$t_n246)
d_n8_ind<-density(post_ind_sel$t_n254)
d_n8_p_ind<-density(prior_sel$t_n254)
d_n3_ind<-density(post_ind_sel$t_n267)
d_n3_p_ind<-density(prior_sel$t_n267)
d_n7_ind<-density(post_ind_sel$t_n285)
d_n7_p_ind<-density(prior_sel$t_n285)
d_n6_ind<-density(post_ind_sel$t_n294)
d_n6_p_ind<-density(prior_sel$t_n294)
d_n12_ind<-density(post_ind_sel$t_n285)
d_n12_p_ind<-density(prior_sel$t_n285)
d_n13_p_ind<-density(prior_sel$t_n270)
d_n13_ind<-density(post_ind_sel$t_n270)

d_n1_corr<-density(post_corr_sel$t_n151)
d_n1_p_ind<-density(prior_sel$t_n151)
d_n2_corr<-density(post_corr_sel$t_n152)
d_n2_p_corr<-density(prior_sel$t_n152)
d_n5_corr<-density(post_corr_sel$t_n153)
d_n5_p_corr<-density(prior_sel$t_n153)
d_n11_corr<-density(post_corr_sel$t_n154)
d_n11_p_corr<-density(prior_sel$t_n154)
d_n15_corr<-density(post_corr_sel$t_n158)
d_n15_p_corr<-density(prior_sel$t_n158)
d_n10_corr<-density(post_corr_sel$t_n229)
d_n10_p_corr<-density(prior_sel$t_n229)
d_n4_corr<-density(post_corr_sel$t_n231)
d_n4_p_corr<-density(prior_sel$t_n231)
d_n9_corr<-density(post_corr_sel$t_n232)
d_n9_p_corr<-density(prior_sel$t_n232)
d_n14_corr<-density(post_corr_sel$t_n246)
d_n14_p_corr<-density(prior_sel$t_n246)
d_n8_corr<-density(post_corr_sel$t_n254)
d_n8_p_corr<-density(prior_sel$t_n254)
d_n3_corr<-density(post_corr_sel$t_n267)
d_n3_p_corr<-density(prior_sel$t_n267)
d_n7_corr<-density(post_corr_sel$t_n285)
d_n7_p_corr<-density(prior_sel$t_n285)
d_n6_corr<-density(post_corr_sel$t_n294)
d_n6_p_corr<-density(prior_sel$t_n294)
d_n12_corr<-density(post_corr_sel$t_n285)
d_n12_p_corr<-density(prior_sel$t_n285)
d_n13_corr<-density(post_corr_sel$t_n270)
d_n13_p_corr<-density(prior_sel$t_n270)

#######Plotting######
pdf("./priorXposterior-allNodes.pdf", width=7, height=10)
par(mfrow=c(8,4),cex.main=0.8,cex.axis=0.7, oma=c(2,2,2,2), mai=c(0.2,0.2,0.2,0.2))

####independent rates##########

plot(d_n1_ind,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 1 independent rates")
par(new=TRUE)
plot(d_n1_p_ind,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)
par(new=TRUE)
plot(prior_1, type="l",xlim=c(0, 1), ylim=c(0, 25),col="orange", axes=NULL)

plot(d_n1_corr,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 1 autocorrelated rates")
par(new=TRUE)
plot(d_n1_p,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)
par(new=TRUE)
plot(prior_1, type="l",xlim=c(0, 1), ylim=c(0, 25),col="orange", axes=NULL)

plot(d_n2_ind,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 2 independent rates")
par(new=TRUE)
plot(d_n2_p_ind,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)
plot(d_n2_corr,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 2 autocorrelated rates")
par(new=TRUE)
plot(d_n2_p_corr,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)

plot(d_n3_ind,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 3 independent rates")
par(new=TRUE)
plot(d_n3_p_ind,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)
plot(d_n3_corr,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 3 autocorrelated rates")
par(new=TRUE)
plot(d_n3_p_corr,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)

plot(d_n4_ind,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 4 independent rates")
par(new=TRUE)
plot(d_n4_p_ind,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)
plot(d_n4_corr,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 4 autocorrelated rates")
par(new=TRUE)
plot(d_n4_p_corr,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)

plot(d_n5_ind,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 5 independent rates")
par(new=TRUE)
plot(prior_5, type="l",xlim=c(0, 1), ylim=c(0, 25),col="orange", axes=NULL)
par(new=TRUE)
plot(d_n5_p_ind,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)
plot(d_n5_corr,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 5 autocorrelated rates")
par(new=TRUE)
plot(prior_5, type="l",xlim=c(0, 1), ylim=c(0, 25),col="orange", axes=NULL)
par(new=TRUE)
plot(d_n5_p_corr,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)

plot(d_n6_ind,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 6 independent rates")
par(new=TRUE)
plot(d_n6_p_ind,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)
plot(d_n6_corr,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 6 autocorrelated rates")
par(new=TRUE)
plot(d_n6_p_corr,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)

plot(d_n7_ind,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 7 independent rates")
par(new=TRUE)
plot(d_n7_p_ind,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)
plot(d_n7_corr,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 7 autocorrelated rates")
par(new=TRUE)
plot(d_n7_p_corr,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)

plot(d_n8_ind,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 8 independent rates")
par(new=TRUE)
plot(d_n8_p_ind,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)
plot(d_n8_corr,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 8 autocorrelated rates")
par(new=TRUE)
plot(d_n8_p_corr,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)

plot(d_n9_ind,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 9 independent rates")
par(new=TRUE)
plot(d_n9_p_ind,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)
plot(d_n9_corr,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 9 autocorrelated rates")
par(new=TRUE)
plot(d_n9_p_corr,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)

plot(d_n10_ind,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 10 independent rates")
par(new=TRUE)
plot(d_n10_p_ind,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)
plot(d_n10_corr,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 10 autocorrelated rates")
par(new=TRUE)
plot(d_n10_p_corr,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)

plot(d_n11_ind,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 11 independent rates")
par(new=TRUE)
plot(d_n11_p_ind,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)
plot(d_n11_corr,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 11 autocorrelated rates")
par(new=TRUE)
plot(d_n11_p_corr,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)

plot(d_n12_ind,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 12 independent rates")
par(new=TRUE)
plot(prior_12, type="l",xlim=c(0, 1), ylim=c(0, 25),col="orange", axes=NULL)
par(new=TRUE)
plot(d_n12_p_ind,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)
plot(d_n12_corr,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 12 autocorrelated rates")
par(new=TRUE)
plot(prior_12, type="l",xlim=c(0, 1), ylim=c(0, 25),col="orange", axes=NULL)
par(new=TRUE)
plot(d_n12_p_corr,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)

plot(d_n13_ind,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 13 independent rates")
par(new=TRUE)
plot(d_n13_p_ind,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)
plot(d_n13_corr,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 13 autocorrelated rates")
par(new=TRUE)
plot(d_n13_p_corr,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)

plot(d_n14_ind,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 14 independent rates")
par(new=TRUE)
plot(d_n14_p_ind,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)
plot(d_n14_corr,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 14 autocorrelated rates")
par(new=TRUE)
plot(d_n14_p_corr,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)

plot(d_n15_ind,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 15 independent rates")
par(new=TRUE)
plot(d_n15_p_ind,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)
plot(d_n15_corr,xlim=c(0, 1), ylim=c(0, 25), col="blue", main="Node 15 autocorrelated rates")
par(new=TRUE)
plot(d_n15_p_corr,xlim=c(0, 1), ylim=c(0, 25), col="red", axes=NULL)


legend("topright", legend=c("user-specified prior", "effective prior", "posterior", axes=NULL),
       col=c("orange","red", "blue"), lty=1, cex=0.7)

dev.off()

