
rm(list=ls()) # clean up the workspace
setwd("D:/Desktop/Eucerinae-datacao/MCMCtree-prepFiles/MCMCTree-126-core-left-right-noOutgroups2/")

# ###############################################
# POSTERIOR 20K:
# ###############################################
# read in MCMC trace files
ind20k.mcmc1<-read.table("./20k/ind/mcmc_1/mcmc_20k_ind.txt", head=TRUE)
ind20k.mcmc2<-read.table("./20k/ind/mcmc_2/mcmc_20k_ind.txt", head=TRUE)
corr20k.mcmc1<-read.table("./20k/corr/mcmc_1/mcmc_20k_corr.txt", head=TRUE)
corr20k.mcmc2<-read.table("./20k/corr/mcmc_2/mcmc_20k_corr.txt", head=TRUE)

names(ind20k.mcmc1)

# to check for convergence of the MCMC runs, we calculate the posterior
# means of times for each run, and plot them against each other
t.ind20k.mean1 <- apply(ind20k.mcmc1[,2:156], 2, mean) * 100
t.ind20k.mean2 <- apply(ind20k.mcmc2[,2:156], 2, mean) * 100
t.corr20k.mean1 <- apply(corr20k.mcmc1[,2:156], 2, mean) * 100
t.corr20k.mean2 <- apply(corr20k.mcmc2[,2:156], 2, mean) * 100

# good convergence is indicated when the points fall on the y = x line.

pdf("./checking_convergence/20k_convergence.pdf", paper = "a4")
par(mfrow=c(3,2),cex.main=1,cex.axis=0.7, oma=c(1,1,1,1), mai=c(0.5,0.5,0.5,0.5))

# posterior times for run 1 vs run 2:
plot(t.ind20k.mean1, t.ind20k.mean2, las=1, main="a) Posterior times, r 1 vs. r 2 IR") 
abline(0, 1)

# notice that ancient times have small ESS
# trace plots are useful to visualise the MCMC and split problems
plot(ind20k.mcmc1$t_n151, las=1, ty='l', main="b) trace of t_n151 IR")
plot(ind20k.mcmc1$t_n152, las=1, ty='l', main="c) trace of t_n152 IR")
plot(ind20k.mcmc1$t_n153, las=1, ty='l', main="c) trace of t_n153 IR")
plot(ind20k.mcmc1$t_n154, las=1, ty='l', main="c) trace of t_n154 IR")

plot(density(ind20k.mcmc1$t_n152), las=1, main="d) histogram of t_n152, r 1 vs. r2 IR")
lines(density(ind20k.mcmc2$t_n152), lty=2)

mtext("Independent rates", outer = TRUE, side = 3)

plot(t.corr20k.mean1, t.corr20k.mean2, las=1, main="a) Posterior times, r 1 vs. r 2 AR")
abline(0, 1)

plot(corr20k.mcmc1$t_n151, ty='l', las=1, main="b) trace of t_n151 AR")
plot(corr20k.mcmc1$t_n152, ty='l', las=1, main="c) trace of t_n152 AR")
plot(corr20k.mcmc1$t_n153, ty='l', las=1, main="c) trace of t_n153 AR")
plot(corr20k.mcmc1$t_n154, ty='l', las=1, main="c) trace of t_n154 AR")

plot(density(corr20k.mcmc1$t_n152), las=1, main="d) histogram of t_n152, r 1 vs. r2 AR")
lines(density(corr20k.mcmc2$t_n152), lty=2)
mtext("Autocorrelated rates", outer = TRUE, side = 3)


dev.off()

####coda ESS####
mean.mcmc <- apply(corr20k.mcmc1[,-1], 2, mean)
ess.mcmc <- apply(corr20k.mcmc1[,-1], 2, coda::effectiveSize)
var.mcmc <- apply(corr20k.mcmc1[,-1], 2, var)
se.mcmc <- sqrt(var.mcmc / ess.mcmc)
corr20K.mcmc1.coda<-cbind(mean.mcmc, ess.mcmc, var.mcmc, se.mcmc)
write.csv(corr20K.mcmc1.coda, "./checking_convergence/corr20K.mcmc1.coda.csv")

mean.mcmc <- apply(corr20k.mcmc2[,-1], 2, mean)
ess.mcmc <- apply(corr20k.mcmc2[,-1], 2, coda::effectiveSize)
var.mcmc <- apply(corr20k.mcmc2[,-1], 2, var)
se.mcmc <- sqrt(var.mcmc / ess.mcmc)
corr20K.mcmc2.coda<-cbind(mean.mcmc, ess.mcmc, var.mcmc, se.mcmc)
write.csv(corr20K.mcmc2.coda, "./checking_convergence/corr20K.mcmc2.coda.csv")

mean.mcmc <- apply(ind20k.mcmc1[,-1], 2, mean)
ess.mcmc <- apply(ind20k.mcmc1[,-1], 2, coda::effectiveSize)
var.mcmc <- apply(ind20k.mcmc1[,-1], 2, var)
se.mcmc <- sqrt(var.mcmc / ess.mcmc)
ind20K.mcmc1.coda<-cbind(mean.mcmc, ess.mcmc, var.mcmc, se.mcmc)
write.csv(ind20K.mcmc1.coda, "./checking_convergence/ind20K.mcmc1.coda.csv")

mean.mcmc <- apply(ind20k.mcmc2[,-1], 2, mean)
ess.mcmc <- apply(ind20k.mcmc2[,-1], 2, coda::effectiveSize)
var.mcmc <- apply(ind20k.mcmc2[,-1], 2, var)
se.mcmc <- sqrt(var.mcmc / ess.mcmc)
ind20K.mcmc2.coda<-cbind(mean.mcmc, ess.mcmc, var.mcmc, se.mcmc)
write.csv(ind20K.mcmc2.coda, "./checking_convergence/ind20K.mcmc2.coda.csv")

# ###############################################
# POSTERIOR 50k:
# ###############################################
# read in MCMC trace files

ind50k.mcmc1<-read.table("./50k/ind/mcmc_1/mcmc_50k_ind.txt", head=TRUE)
ind50k.mcmc2<-read.table("./50k/ind/mcmc_2/mcmc_50k_ind.txt", head=TRUE)
corr50k.mcmc1<-read.table("./50k/corr/mcmc_1/combined/mcmc_50k_corr.txt", head=TRUE)
corr50k.mcmc2<-read.table("./50k/corr/mcmc_2/combined/mcmc_50k_corr.txt", head=TRUE)

t.ind50k.mean1 <- apply(ind50k.mcmc1[,2:156], 2, mean) * 100
t.ind50k.mean2 <- apply(ind50k.mcmc2[,2:156], 2, mean) * 100
t.corr50k.mean1 <- apply(corr50k.mcmc1[,2:156], 2, mean) * 100
t.corr50k.mean2 <- apply(corr50k.mcmc2[,2:156], 2, mean) * 100

# good convergence is indicated when the points fall on the y = x line.

pdf("./checking_convergence/50k_convergence.pdf", paper = "a4")
par(mfrow=c(3,2),cex.main=1,cex.axis=0.7, oma=c(1,1,1,1), mai=c(0.5,0.5,0.5,0.5))
# posterior times for run 1 vs run 2:
plot(t.ind50k.mean1, t.ind50k.mean2, las=1, main="a) Posterior times, r 1 vs. r 2 IR"); abline(0, 1)

# notice that ancient times (t_n11 and t_n12) have small ESS
# trace plots are useful to visualise the MCMC and split problems
plot(ind50k.mcmc1$t_n151, ty='l', las=1, main="b) trace of t_n151 IR")
plot(ind50k.mcmc1$t_n152, ty='l', las=1, main="c) trace of t_n152 IR")
plot(ind50k.mcmc1$t_n153, ty='l', las=1, main="c) trace of t_n153 IR")
plot(ind50k.mcmc1$t_n154, ty='l', las=1, main="c) trace of t_n154 IR")

plot(density(ind50k.mcmc1$t_n152), las=1, main="d) histogram of t_n152, r 1 vs. r2 IR")
lines(density(ind50k.mcmc2$t_n152), lty=2)
mtext("Independent rates", outer = TRUE, side = 3)

plot(t.corr50k.mean1, t.corr50k.mean2, main="a) Posterior times, r 1 vs. r 2 AR"); abline(0, 1)
plot(corr50k.mcmc1$t_n151, ty='l', las=1, main="b) trace of t_n151 AR")
plot(corr50k.mcmc1$t_n152, ty='l', las=1, main="c) trace of t_n152 AR")
plot(corr50k.mcmc1$t_n153, ty='l', las=1, main="c) trace of t_n153 AR")
plot(corr50k.mcmc1$t_n154, ty='l', las=1, main="c) trace of t_n154 AR")

plot(density(corr50k.mcmc1$t_n152), las=1, main="d) histogram of t_n152, r 1 vs. r2 AR")
lines(density(corr50k.mcmc2$t_n152), lty=2)
mtext("Autocorrelated rates", outer = TRUE, side = 3)

dev.off()


####coda ESS####
mean.mcmc <- apply(corr50k.mcmc1[,-1], 2, mean)
ess.mcmc <- apply(corr50k.mcmc1[,-1], 2, coda::effectiveSize)
var.mcmc <- apply(corr50k.mcmc1[,-1], 2, var)
se.mcmc <- sqrt(var.mcmc / ess.mcmc)
corr50k.mcmc1.coda<-cbind(mean.mcmc, ess.mcmc, var.mcmc, se.mcmc)
write.csv(corr50k.mcmc1.coda, "./checking_convergence/corr50k.mcmc1.coda.csv")

mean.mcmc <- apply(corr50k.mcmc2[,-1], 2, mean)
ess.mcmc <- apply(corr50k.mcmc2[,-1], 2, coda::effectiveSize)
var.mcmc <- apply(corr50k.mcmc2[,-1], 2, var)
se.mcmc <- sqrt(var.mcmc / ess.mcmc)
corr50k.mcmc2.coda<-cbind(mean.mcmc, ess.mcmc, var.mcmc, se.mcmc)
write.csv(corr50k.mcmc2.coda, "./checking_convergence/corr50k.mcmc2.coda.csv")

mean.mcmc <- apply(ind50k.mcmc1[,-1], 2, mean)
ess.mcmc <- apply(ind50k.mcmc1[,-1], 2, coda::effectiveSize)
var.mcmc <- apply(ind50k.mcmc1[,-1], 2, var)
se.mcmc <- sqrt(var.mcmc / ess.mcmc)
ind50k.mcmc1.coda<-cbind(mean.mcmc, ess.mcmc, var.mcmc, se.mcmc)
write.csv(ind50k.mcmc1.coda, "./checking_convergence/ind50k.mcmc1.coda.csv")

mean.mcmc <- apply(ind50k.mcmc2[,-1], 2, mean)
ess.mcmc <- apply(ind50k.mcmc2[,-1], 2, coda::effectiveSize)
var.mcmc <- apply(ind50k.mcmc2[,-1], 2, var)
se.mcmc <- sqrt(var.mcmc / ess.mcmc)
ind50k.mcmc2.coda<-cbind(mean.mcmc, ess.mcmc, var.mcmc, se.mcmc)
write.csv(ind50k.mcmc2.coda, "./checking_convergence/ind50k.mcmc2.coda.csv")

# ###############################################
# POSTERIOR 70K:
# ###############################################
# read in MCMC trace files

ind70k.mcmc1 <- read.table("./70k/ind/mcmc_1/2/mcmc_70k_ind.txt", head=TRUE)
ind70k.mcmc2 <- read.table("./70k/ind/mcmc_2/2/mcmc_70k_ind.txt", head=TRUE)
corr70k.mcmc1<-read.table("./70k/corr/combined/mcmc_70k_corr1.txt", head=TRUE)
corr70k.mcmc2<-read.table("./70k/corr/combined/mcmc_70k_corr2.1.txt", head=TRUE)

t.ind70k.mean1 <- apply(ind70k.mcmc1[,2:156], 2, mean) * 100
t.ind70k.mean2 <- apply(ind70k.mcmc2[,2:156], 2, mean) * 100
t.corr70k.mean1 <- apply(corr70k.mcmc1[,2:156], 2, mean) * 100
t.corr70k.mean2 <- apply(corr70k.mcmc2[,2:156], 2, mean) * 100

# good convergence is indicated when the points fall on the y = x line.

pdf("./checking_convergence/70k_convergence.pdf", paper = "a4")
par(mfrow=c(3,2),cex.main=1,cex.axis=0.7, oma=c(1,1,1,1), mai=c(0.5,0.5,0.5,0.5))
# posterior times for run 1 vs run 2:
plot(t.ind70k.mean1, t.ind70k.mean2, las=1, main="a) Posterior times, r 1 vs. r 2 IR"); abline(0, 1)

# notice that ancient times (t_n11 and t_n12) have small ESS
# trace plots are useful to visualise the MCMC and split problems
plot(ind70k.mcmc1$t_n151, ty='l', las=1, main="b) trace of t_n151 IR")
plot(ind70k.mcmc1$t_n152, ty='l', las=1, main="c) trace of t_n152 IR")
plot(ind70k.mcmc1$t_n153, ty='l', las=1, main="c) trace of t_n153 IR")
plot(ind70k.mcmc1$t_n154, ty='l', las=1, main="c) trace of t_n154 IR")

plot(density(ind70k.mcmc1$t_n152), las=1, main="d) histogram of t_n152, r 1 vs. r2 IR")
lines(density(ind70k.mcmc2$t_n152), lty=2)
mtext("Independent rates", outer = TRUE, side = 3)

plot(t.corr70k.mean1, t.corr70k.mean2, las=1, main="a) Posterior times, r 1 vs. r 2 AR"); abline(0, 1)
plot(corr70k.mcmc1$t_n151, ty='l', las=1, main="b) trace of t_n151 AR")
plot(corr70k.mcmc1$t_n152, ty='l', las=1, main="c) trace of t_n152 AR")
plot(corr70k.mcmc1$t_n153, ty='l', las=1, main="c) trace of t_n153 AR")
plot(corr70k.mcmc1$t_n154, ty='l', las=1, main="c) trace of t_n154 AR")

plot(density(corr70k.mcmc1$t_n152), las=1, main="d) histogram of t_n152, r 1 vs. r2 AR")
lines(density(corr70k.mcmc2$t_n152), lty=2)
mtext("Autocorrelated rates", outer = TRUE, side = 3)

dev.off()


####coda ESS####
mean.mcmc <- apply(corr70k.mcmc1[,-1], 2, mean)
ess.mcmc <- apply(corr70k.mcmc1[,-1], 2, coda::effectiveSize)
var.mcmc <- apply(corr70k.mcmc1[,-1], 2, var)
se.mcmc <- sqrt(var.mcmc / ess.mcmc)
corr70k.mcmc1.coda<-cbind(mean.mcmc, ess.mcmc, var.mcmc, se.mcmc)
write.csv(corr70k.mcmc1.coda, "./checking_convergence/corr70k.mcmc1.coda.csv")

mean.mcmc <- apply(corr70k.mcmc2[,-1], 2, mean)
ess.mcmc <- apply(corr70k.mcmc2[,-1], 2, coda::effectiveSize)
var.mcmc <- apply(corr70k.mcmc2[,-1], 2, var)
se.mcmc <- sqrt(var.mcmc / ess.mcmc)
corr70k.mcmc2.coda<-cbind(mean.mcmc, ess.mcmc, var.mcmc, se.mcmc)
write.csv(corr70k.mcmc2.coda, "./checking_convergence/corr70k.mcmc2.coda.csv")

mean.mcmc <- apply(ind70k.mcmc1[,-1], 2, mean)
ess.mcmc <- apply(ind70k.mcmc1[,-1], 2, coda::effectiveSize)
var.mcmc <- apply(ind70k.mcmc1[,-1], 2, var)
se.mcmc <- sqrt(var.mcmc / ess.mcmc)
ind70k.mcmc1.coda<-cbind(mean.mcmc, ess.mcmc, var.mcmc, se.mcmc)
write.csv(ind70k.mcmc1.coda, "./checking_convergence/ind70k.mcmc1.coda.csv")

mean.mcmc <- apply(ind70k.mcmc2[,-1], 2, mean)
ess.mcmc <- apply(ind70k.mcmc2[,-1], 2, coda::effectiveSize)
var.mcmc <- apply(ind70k.mcmc2[,-1], 2, var)
se.mcmc <- sqrt(var.mcmc / ess.mcmc)
ind70k.mcmc2.coda<-cbind(mean.mcmc, ess.mcmc, var.mcmc, se.mcmc)
write.csv(ind70k.mcmc2.coda, "./checking_convergence/ind70k.mcmc2.coda.csv")

# ###############################################
# POSTERIOR 20K umpartitioned:
# ###############################################
# read in MCMC trace files
ind20kunp.mcmc1<-read.table("./unpartitioned-20k/ind/mcmc_1/mcmc_20k_ind.txt", head=TRUE)
ind20kunp.mcmc2<-read.table("./unpartitioned-20k/ind/mcmc_2/mcmc_20k_ind.txt", head=TRUE)
corr20kunp.mcmc1<-read.table("./unpartitioned-20k/corr/mcmc_1/mcmc_20k_corr.txt", head=TRUE)
corr20kunp.mcmc2<-read.table("./unpartitioned-20k/corr/mcmc_2/mcmc_20k_corr.txt", head=TRUE)

names(ind20kunp.mcmc1)

# to check for convergence of the MCMC runs, we calculate the posterior
# means of times for each run, and plot them against each other
t.ind20kunp.mean1 <- apply(ind20kunp.mcmc1[,2:149], 2, mean) * 100
t.ind20kunp.mean2 <- apply(ind20kunp.mcmc2[,2:149], 2, mean) * 100
t.corr20kunp.mean1 <- apply(corr20kunp.mcmc1[,2:149], 2, mean) * 100
t.corr20kunp.mean2 <- apply(corr20kunp.mcmc2[,2:149], 2, mean) * 100

# good convergence is indicated when the points fall on the y = x line.

pdf("./checking_convergence/20k_umpartitioned_convergence.pdf", paper = "a4")
par(mfrow=c(3,2),cex.main=1,cex.axis=0.7, oma=c(1,1,1,1), mai=c(0.5,0.5,0.5,0.5))

# posterior times for run 1 vs run 2:
plot(t.ind20kunp.mean1, t.ind20kunp.mean2, las=1, main="a) Posterior times, r 1 vs. r 2 IR") 
abline(0, 1)

# notice that ancient times (t_n11 and t_n12) have small ESS
# trace plots are useful to visualise the MCMC and split problems
plot(ind20kunp.mcmc1$t_n151, las=1, ty='l', main="b) trace of t_n151 IR")
plot(ind20kunp.mcmc1$t_n152, las=1, ty='l', main="c) trace of t_n152 IR")
plot(ind20kunp.mcmc1$t_n153, las=1, ty='l', main="c) trace of t_n153 IR")
plot(ind20kunp.mcmc1$t_n154, las=1, ty='l', main="c) trace of t_n154 IR")

plot(density(ind20kunp.mcmc1$t_n152), las=1, main="d) histogram of t_n152, r 1 vs. r2 IR")
lines(density(ind20kunp.mcmc2$t_n152), lty=2)

mtext("Independent rates", outer = TRUE, side = 3)

plot(t.corr20kunp.mean1, t.corr20kunp.mean2, las=1, main="a) Posterior times, r 1 vs. r 2 AR")
abline(0, 1)

plot(corr20kunp.mcmc1$t_n151, ty='l', las=1, main="b) trace of t_n151 AR")
plot(corr20kunp.mcmc1$t_n152, ty='l', las=1, main="c) trace of t_n152 AR")
plot(corr20kunp.mcmc1$t_n153, ty='l', las=1, main="c) trace of t_n153 AR")
plot(corr20kunp.mcmc1$t_n154, ty='l', las=1, main="c) trace of t_n154 AR")

plot(density(corr20kunp.mcmc1$t_n152), las=1, main="d) histogram of t_n152, r 1 vs. r2 AR")
lines(density(corr20kunp.mcmc2$t_n152), lty=2)
mtext("Autocorrelated rates", outer = TRUE, side = 3)


dev.off()

####coda ESS####
mean.mcmc <- apply(corr20kunp.mcmc1[,-1], 2, mean)
ess.mcmc <- apply(corr20kunp.mcmc1[,-1], 2, coda::effectiveSize)
var.mcmc <- apply(corr20kunp.mcmc1[,-1], 2, var)
se.mcmc <- sqrt(var.mcmc / ess.mcmc)
corr20Kunp.mcmc1.coda<-cbind(mean.mcmc, ess.mcmc, var.mcmc, se.mcmc)
write.csv(corr20Kunp.mcmc1.coda, "./checking_convergence/corr20Kunp.mcmc1.coda.csv")

mean.mcmc <- apply(corr20kunp.mcmc2[,-1], 2, mean)
ess.mcmc <- apply(corr20kunp.mcmc2[,-1], 2, coda::effectiveSize)
var.mcmc <- apply(corr20kunp.mcmc2[,-1], 2, var)
se.mcmc <- sqrt(var.mcmc / ess.mcmc)
corr20Kunp.mcmc2.coda<-cbind(mean.mcmc, ess.mcmc, var.mcmc, se.mcmc)
write.csv(corr20Kunp.mcmc2.coda, "./checking_convergence/corr20Kunp.mcmc2.coda.csv")

mean.mcmc <- apply(ind20kunp.mcmc1[,-1], 2, mean)
ess.mcmc <- apply(ind20kunp.mcmc1[,-1], 2, coda::effectiveSize)
var.mcmc <- apply(ind20kunp.mcmc1[,-1], 2, var)
se.mcmc <- sqrt(var.mcmc / ess.mcmc)
ind20Kunp.mcmc1.coda<-cbind(mean.mcmc, ess.mcmc, var.mcmc, se.mcmc)
write.csv(ind20Kunp.mcmc1.coda, "./checking_convergence/ind20Kunp.mcmc1.coda.csv")

mean.mcmc <- apply(ind20kunp.mcmc2[,-1], 2, mean)
ess.mcmc <- apply(ind20kunp.mcmc2[,-1], 2, coda::effectiveSize)
var.mcmc <- apply(ind20kunp.mcmc2[,-1], 2, var)
se.mcmc <- sqrt(var.mcmc / ess.mcmc)
ind20Kunp.mcmc2.coda<-cbind(mean.mcmc, ess.mcmc, var.mcmc, se.mcmc)
write.csv(ind20Kunp.mcmc2.coda, "./checking_convergence/ind20Kunp.mcmc2.coda.csv")

# ###############################################
# PRIORx20k:
# ###############################################
ind.mcmc.p <- read.table("./prior/ind/mcmc_20k_ind.txt", head=TRUE)
corr.mcmc.p <- read.table("./prior/corr/mcmc_20k_corr.txt", head=TRUE)

ind.p.mean <- apply(ind.mcmc.p[,2:156], 2, mean) * 100
corr.p.mean <- apply(corr.mcmc.p[,2:156], 2, mean) * 100

pdf("./checking_convergence/piorXposterior_20k.pdf", width=11.7, height=16.5)
par(mfrow=c(19,8),cex.main=0.8,cex.axis=0.5, oma=c(2,2,2,2), mai=c(0.2,0.2,0.2,0.2))
for(i in 149:1) {
  dpr <- density(ind.mcmc.p[,i+1], adj=.1) # prior
  dPr <- density(ind20k.mcmc1[,i+1], adj=.1)   # Posterior
  xl <- range(c(dpr$x, dPr$x))
  yl <- range(c(dpr$y, dPr$y))
  plot(dpr, main=paste("t_n",i+150,sep=""), xlab="", ylab="", las=1, xlim=xl, ylim=yl, col="darkgrey")
  lines(dPr, col="black")
}
mtext("Independet rates", outer = TRUE, side = 3)

plot.new()
plot.new()
plot.new()

for(i in 149:1) {
  dpr <- density(corr.mcmc.p[,i+1], adj=.1) # prior
  dPr <- density(corr20k.mcmc1[,i+1], adj=.1)   # Posterior
  xl <- range(c(dpr$x, dPr$x))
  yl <- range(c(dpr$y, dPr$y))
  plot(dpr, main=paste("t_n",i+150,sep=""), xlab="", ylab="", las=1, xlim=xl, ylim=yl, col="darkgrey", new=TRUE)
  lines(dPr, col="black")
}
mtext("Autocorrelated rates", outer = TRUE, side = 3)

dev.off()

# ###############################################
# PRIORx50k:
# ###############################################
pdf("./checking_convergence/piorXposterior_50k.pdf", width=11.7, height=16.5)
par(mfrow=c(19,8),cex.main=0.8,cex.axis=0.5, oma=c(2,2,2,2), mai=c(0.2,0.2,0.2,0.2))
for(i in 149:1) {
  dpr <- density(ind.mcmc.p[,i+1], adj=.1) # prior
  dPr <- density(ind50k.mcmc1[,i+1], adj=.1)   # Posterior
  xl <- range(c(dpr$x, dPr$x))
  yl <- range(c(dpr$y, dPr$y))
  plot(dpr, main=paste("t_n",i+150,sep=""), xlab="", ylab="", las=1, xlim=xl, ylim=yl, col="darkgrey")
  lines(dPr, col="black")
}
mtext("Independet rates", outer = TRUE, side = 3)

plot.new()
plot.new()
plot.new()

for(i in 149:1) {
  dpr <- density(corr.mcmc.p[,i+1], adj=.1) # prior
  dPr <- density(corr50k.mcmc1[,i+1], adj=.1)   # Posterior
  xl <- range(c(dpr$x, dPr$x))
  yl <- range(c(dpr$y, dPr$y))
  plot(dpr, main=paste("t_n",i+150,sep=""), xlab="", ylab="", las=1, xlim=xl, ylim=yl, col="darkgrey", new=TRUE)
  lines(dPr, col="black")
}
mtext("Autocorrelated rates", outer = TRUE, side = 3)

dev.off()

# ###############################################
# PRIORx70k:
# ###############################################
pdf("./checking_convergence/piorXposterior_70k.pdf", width=11.7, height=16.5)
par(mfrow=c(19,8),cex.main=0.8,cex.axis=0.5, oma=c(2,2,2,2), mai=c(0.2,0.2,0.2,0.2))
for(i in 149:1) {
  dpr <- density(ind.mcmc.p[,i+1], adj=.1) # prior
  dPr <- density(ind70k.mcmc1[,i+1], adj=.1)   # Posterior
  xl <- range(c(dpr$x, dPr$x))
  yl <- range(c(dpr$y, dPr$y))
  plot(dpr, main=paste("t_n",i+150,sep=""), xlab="", ylab="", las=1, xlim=xl, ylim=yl, col="darkgrey")
  lines(dPr, col="black")
}
mtext("Independet rates", outer = TRUE, side = 3)

plot.new()
plot.new()
plot.new()


for(i in 149:1) {
  dpr <- density(corr.mcmc.p[,i+1], adj=.1) # prior
  dPr <- density(corr70k.mcmc1[,i+1], adj=.1)   # Posterior
  xl <- range(c(dpr$x, dPr$x))
  yl <- range(c(dpr$y, dPr$y))
  plot(dpr, main=paste("t_n",i+150,sep=""), xlab="", ylab="", las=1, xlim=xl, ylim=yl, col="darkgrey", new=TRUE)
  lines(dPr, col="black")
}
mtext("Autocorrelated rates", outer = TRUE, side = 3)

dev.off()


# ###############################################
# PRIORx20k umpart:
# ###############################################
pdf("./checking_convergence/piorXposterior_20kump.pdf", width=11.7, height=16.5)
par(mfrow=c(19,8),cex.main=0.8,cex.axis=0.5, oma=c(2,2,2,2), mai=c(0.2,0.2,0.2,0.2))
for(i in 149:1) {
  dpr <- density(ind.mcmc.p[,i+1], adj=.1) # prior
  dPr <- density(ind20kunp.mcmc1[,i+1], adj=.1)   # Posterior
  xl <- range(c(dpr$x, dPr$x))
  yl <- range(c(dpr$y, dPr$y))
  plot(dpr, main=paste("t_n",i+150,sep=""), xlab="", ylab="", las=1, xlim=xl, ylim=yl, col="darkgrey")
  lines(dPr, col="black")
}
mtext("Independet rates", outer = TRUE, side = 3)

plot.new()
plot.new()
plot.new()


for(i in 149:1) {
  dpr <- density(corr.mcmc.p[,i+1], adj=.1) # prior
  dPr <- density(corr20kunp.mcmc1[,i+1], adj=.1)   # Posterior
  xl <- range(c(dpr$x, dPr$x))
  yl <- range(c(dpr$y, dPr$y))
  plot(dpr, main=paste("t_n",i+150,sep=""), xlab="", ylab="", las=1, xlim=xl, ylim=yl, col="darkgrey", new=TRUE)
  lines(dPr, col="black")
}
mtext("Autocorrelated rates", outer = TRUE, side = 3)

dev.off()
