library(RevGadgets)
library(ggimage)
library(dplyr)
library(tidyr)
library(reshape2)

#setwd("D:/Desktop/Eucerinae-datacao/RevBayes-DEC/RevBayes_Win_1.1.0/")

# file names
fp = "./"
out_str = "Eucerinae_simple_AR/"
out_fn = paste(out_str,"/",out_str,".range.pdf",sep="")
tree_fn = paste(fp, "Eucerinae_simple_AR/output_10000gen_simple-nodist_BF.ase.tre", sep="")
label_fn = paste(fp, "Eucerinae_simple_AR/output_10000gen_simple-nodist_BF.state_labels.txt", sep="")
color_fn = paste(fp, "Eucerinae_simple_AR/Eu_range_colors.txt", sep="")

# area labels
area_names = c("sSA","nSA","N","O")

# get state labels
state_descriptions = read.csv(label_fn, header=T, sep=",", colClasses="character")
state_descriptions
# map presence-absence ranges to area names
range_labels = sapply(state_descriptions$range[2:nrow(state_descriptions)],
                      function(x) {
                        present = as.vector(gregexpr(pattern="1", x)[[1]])
                        paste( area_names[present], collapse="")
                      })
range_labels
# generate colors for ranges
range_color_list = read.csv(color_fn, header=T, sep=",", colClasses="character")
range_colors = range_color_list$color[ match(range_color_list$range, range_labels) ]
range_color_list

idx = 1
st_lbl = list()
st_colors = c()
for (j in 1:15) {
  st_lbl[[ as.character(j) ]] = range_labels[j]
  st_colors[j] = range_colors[j]
}
# use "..." to represent remaining low-prob states
st_colors[ length(st_colors)+1 ] = "lightgray"
st_lbl[["misc."]] = "misc."


st_lbl
st_colors
# plot range
pp=plot_ancestral_states(tree_file=tree_fn,
                         include_start_states=T,
                         shoulder_label_size=1.5,
                         summary_statistic="PieRange",
                         state_labels=st_lbl,
                         state_colors=st_colors,
                         node_label_size=2,
                         node_size_range=c(0.5,2),
                         node_label_nudge_x=0.5,
                         tip_node_size=2,
                         tip_label_size=1.8,
                         tip_label_offset=0.1,
                         xlim_visible=c(-1,22),
                         shoulder_label_nudge_x=0.0,
                         show_posterior_legend=T,
                         node_pie_diameter=3,
                         tip_pie_diameter=2.5,
                         pie_nudge_x=0.08,
                         pie_nudge_y=0.16,
                         alpha=1,
                         fig_width=7,
                         fig_height=5)
pp
ggsave(file="Eucerinae_DEC.pdf", device="pdf",height=8.3,width=11.7, useDingbats=F)

# get states for all nodes in tree
# we will join this to the parent node in the tree data
# hence rename end_state_1 to parent_end_state_1
node_states <- pp$data %>% select(node, end_state_1) %>%
  rename(parent_end_state_1 = end_state_1)


# join parent node states into tree data
pp_with_parent_states <- left_join(pp$data, node_states, by = c("parent" = "node")) %>%
  rename(node_end_state_1 = end_state_1)


# select columns for parent node, parent state, node and node state
pp_selection <- pp_with_parent_states %>%
  select(parent, parent_end_state_1, node, node_end_state_1)


# filter for state shifts and get counts and rates!
pp_shifts <- pp_selection %>%
  mutate(type = ifelse(parent_end_state_1 == node_end_state_1, "conserved", "shift")) %>%
  filter(type == "shift") %>%
  mutate(shift = paste(parent_end_state_1, node_end_state_1, sep="-")) %>%
  count(shift) %>%
  mutate(rate = n/sum(n))


pp_shifts
write.csv2(pp_shifts, paste(fp,out_str,"pp_shifts.csv",sep=""))